@@ -18,6 +18,7 @@ from .cli import (
 from .parsers import (
     save_text_as_source,
     save_file_as_source,
+    parse_links_memory,
 )
 from .index.schema import Link
 from .util import enforce_types                         # type: ignore
@@ -51,12 +52,13 @@ from .index.sql import (
     remove_from_sql_main_index,
 )
 from .index.html import parse_html_main_index
-from .extractors import archive_links
+from .extractors import archive_links, archive_link, ignore_methods
 from .config import (
     stderr,
     ConfigDict,
     ANSI,
-    # IS_TTY,
+    IS_TTY,
+    IN_DOCKER,
     USER,
     ARCHIVEBOX_BINARY,
     ONLY_NEW,
@@ -177,6 +179,10 @@ def help(out_dir: str=OUTPUT_DIR) -> None:
     else:
         print('{green}Welcome to ArchiveBox v{}!{reset}'.format(VERSION, **ANSI))
         print()
+        if IN_DOCKER:
+            print('When using Docker, you need to mount a volume to use as your data dir:')
+            print('    docker run -v /some/path:/data archivebox ...')
+            print()
         print('To import an existing archive (from a previous version of ArchiveBox):')
         print('    1. cd into your data dir OUTPUT_DIR (usually ArchiveBox/output) and run:')
         print('    2. archivebox init')
@@ -493,6 +499,23 @@ def status(out_dir: str=OUTPUT_DIR) -> None:
     print(ANSI['black'], '   ...', ANSI['reset'])
 
 
+@enforce_types
+def oneshot(url: str, out_dir: str=OUTPUT_DIR):
+    """
+    Create a single URL archive folder with an index.json and index.html, and all the archive method outputs.
+    You can run this to archive single pages without needing to create a whole collection with archivebox init.
+    """
+    oneshot_link, _ = parse_links_memory([url])
+    if len(oneshot_link) > 1:
+        stderr(
+                '[X] You should pass a single url to the oneshot command',
+                color='red'
+            )
+        raise SystemExit(2)
+    methods = ignore_methods(['title'])
+    archive_link(oneshot_link[0], out_dir=out_dir, methods=methods, skip_index=True)
+    return oneshot_link
+
 @enforce_types
 def add(urls: Union[str, List[str]],
         depth: int=0,
@@ -1039,10 +1062,14 @@ def manage(args: Optional[List[str]]=None, out_dir: str=OUTPUT_DIR) -> None:
     """Run an ArchiveBox Django management command"""
 
     check_data_folder(out_dir=out_dir)
-
     setup_django(out_dir)
     from django.core.management import execute_from_command_line
 
+    if (args and "createsuperuser" in args) and (IN_DOCKER and not IS_TTY):
+        stderr('[!] Warning: you need to pass -it to use interactive commands in docker', color='lightyellow')
+        stderr('    docker run -it archivebox manage {}'.format(' '.join(args or ['...'])), color='lightyellow')
+        stderr()
+
     execute_from_command_line([f'{ARCHIVEBOX_BINARY} manage', *(args or ['help'])])
 
 
@@ -1055,3 +1082,4 @@ def shell(out_dir: str=OUTPUT_DIR) -> None:
     setup_django(OUTPUT_DIR)
     from django.core.management import call_command
     call_command("shell_plus")
+
